@@ -20,8 +20,8 @@ handle_file_id <- function(obj) {
 
 #' Issue a get request for a file stored on box.com
 #' 
-#' This internal function is shared by \code{\link{box_dl}}, and the 
-#' \code{\link{box_read}} family of functions, to issue GET requests, while
+#' This internal function is shared by [box_dl()], and the 
+#' [box_read()] family of functions, to issue GET requests, while
 #' handling things like version numbers etc. It can be used to download a file,
 #' or just read it into memory.
 #' 
@@ -81,8 +81,8 @@ boxGet <- function(file_id, local_file, version_id = NULL, version_no = NULL,
         httr::write_disk(local_file, TRUE),
       if (pb)
         httr::progress(),
-      httr::config(token = getOption("boxr.token"))
-    ) 
+      get_token()
+    )
   } else {
     # The call without the version url parameter (e.g the latest version)
     req <- httr::GET(
@@ -94,7 +94,7 @@ boxGet <- function(file_id, local_file, version_id = NULL, version_no = NULL,
         httr::write_disk(local_file, TRUE),
       if (pb)
         httr::progress(),
-      httr::config(token = getOption("boxr.token"))
+      get_token()
     ) 
   }
   
