@@ -1,84 +1,84 @@
-#' Download and upload individual files from box.com
+#' Download/upload files from/to Box
 #' 
-#' @description {
-#'   Functions to download (\code{box_dl}), and upload (\code{box_ul}).
+#' @description
 #' 
-#'   \code{box_dl} takes the \code{id} of a file hosted on box.com, downloads 
-#'     it and writes it to disk.
-#' 
-#'   \code{box_ul} uploads a file stored locally to a specified box.com folder.
-#'     If a file with the same name already exists, it will upload the file as
-#'     a new version.
+#' \describe{
+#'   \item{`box_dl()`}{download a file from Box to a local directory}
+#'   \item{`box_ul()`}{upload a local file to a Box folder}
 #' }
 #' 
 #' @section Versions:
-#'   \describe{
-#'     \code{box_dl} can accept one of two parameters to specify file versions:
-#'     \bold{\code{version_id}} and \bold{\code{version_no}}.
-#'     
-#'     The box.com API refers to file versions using 11 digit ids (which can be
-#'     accessed via \code{\link{box_previous_versions}}) - you can specify these
-#'     using the \code{version_id} parameter.
-#'     
-#'     However, this isn't terribly intuative. As a result, \code{box_dl} 
-#'     provides the \code{version_no} parameter, which accepts a whole number, 
-#'     and corresponds to the versions that you'll see via the web UI. For 
-#'     example to download the version marked 'V2' on box.com, specify
-#'     \code{version_no = 2}. This works by making an internal call to 
-#'     \code{\link{box_previous_versions}} to retrieve the \code{version_id},
-#'     which makes it slightly slower.
-#'   }
 #' 
-#' @param file_id The box.com id for the file that you'd like to download
-#' @param overwrite \code{logical}. Should existing files with the same name be 
-#'   overwritten?
-#' @param local_dir A file path to a local directory which you'd like the file
-#'   to be downloaded to.
-#' @param filename Optional. An alternate filename for the local version of the 
-#'   file. The default, \code{NULL}, uses the name from box.com.
-#' @param file the path to the local file that you'd like to upload (if there is
-#'  one)
-#' @param dir_id If uploading, the box.com folder id that you'd like to upload
-#'   to.
-#' @param version_id If downloading an older version, the \code{version_id} of 
-#'   the desired file
-#' @param version_no The version of the file you'd like to download (starting at
-#'   1)
-#' @param pb Should a progress bar be shown? (via 
-#'   \code{\link{setTxtProgressBar}})
-#' @param description Optional. \code{character}. A string to be used as the
-#'   description caption for the file (added via 
-#'   \code{\link{box_add_description}}). Useful for describing the contents of a
-#'   file, or describing the latest changes made to it. If \code{NULL} (the 
-#'   default), no description is added.
+#' `box_dl()` can accept one of two parameters to specify file versions:
+#' **`version_id`** or **`version_no`**.
+#' 
+#' The box.com API refers to file versions using 11 digit ids (which can be
+#' accessed via [box_previous_versions()]) - you can specify these
+#' using the `version_id` parameter.
+#' 
+#' However, this isn't terribly intuitive. As a result, `box_dl()` 
+#' provides the `version_no` parameter, which accepts a whole number, 
+#' and corresponds to the versions that you'll see via the web UI. For 
+#' example to download the version marked 'V2' on box.com, specify
+#' `version_no = 2`. This works by making an internal call to 
+#' [box_previous_versions()] to retrieve the `version_id`,
+#' which makes it slightly slower.
+#' 
+#' @inheritParams box_fetch
+#' @param file_id `numeric` or `character`, file ID at Box. 
+#' @param file_name `character`, if supplied, an alternate filename 
+#'   for the local version of the Box file. 
+#' @param file `character`, local path to the file.
+#' @param version_id `character` or `numeric`, the `version_id` of the file.
+#' @param version_no `numeric`, version of the file you'd like to download
+#'   (starting at 1).
+#' @param pb `logical`, indicates to show progress bar
+#'   (via [setTxtProgressBar()]).
+#' @param description `character`, description caption for the file. 
+#' @param filename `character`, **deprecated**: use `file_name` instead.
 #' 
 #' @return
-#'   \code{box_dl} returns the path of the newly downloaded file if successful,
-#'     and throw an error otherwise.
-#'   
-#'   \code{box_ul} will return an object of class 
-#'   \code{\link[=boxr_S3_classes]{boxr_file_reference}}
 #' 
-#' @author Brendan Rocks \email{foss@@brendanrocks.com}
+#' \describe{
+#'   \item{`box_dl()`}{`character`, local path to the downloaded file.}
+#'   \item{`box_ul()`}{Object with S3 class [`boxr_file_reference`][boxr_S3_classes].}
+#' }
 #' 
-#' @seealso \code{\link{box_fetch}} and \code{\link{box_push}} for 
-#'   directory-wide equivalents, \code{\link{box_delete_file}} for removing 
-#'   uploaded files, \code{\link{box_source}} for R code, and 
-#'   \code{\link{box_save}}/\code{\link{box_load}} for remote R objects.
+#' @seealso
+#' * [box_fetch()] and [box_push()] for 
+#'   directory-wide equivalents.
+#' * [box_delete_file()] for removing 
+#'   uploaded files.
+#' * [box_source()] for R code.
+#' * [box_save()]/[box_load()] for remote R objects.
 #' 
 #' @export
 box_dl <- function(file_id, local_dir = getwd(), overwrite = FALSE, 
-                   filename = NULL, version_id = NULL, version_no = NULL,
-                   pb = options()$boxr.progress) {
+                   file_name = NULL, version_id = NULL, version_no = NULL,
+                   pb = options()$boxr.progress, filename) {
   
   checkAuth()
   assertthat::assert_that(assertthat::is.dir(local_dir))
   assertthat::assert_that(!is.na(overwrite))
   assertthat::assert_that(is.logical(overwrite))
   
-  # If the user's supplied a filename that's already present 
+  
+  # TODO: in future version, remove argument
+  if (!missing(filename)) {
+    
+    warning(
+      "argument `filename` is deprecated; please use `file_name` instead.", 
+      call. = FALSE
+    )
+    
+    if (is.null(file_name)) {
+      file_name <- filename
+    }
+  }
+  
+  # If the user's supplied a file_name that's already present 
   # & overwrite == FALSE, fail early
-  if (!overwrite & !is.null(filename) && file.exists(filename))
+  if (!overwrite & !is.null(file_name) && file.exists(file_name))
     stop("File already exists locally, and overwrite = FALSE")
   
   # Get a temp file
@@ -98,12 +98,12 @@ box_dl <- function(file_id, local_dir = getwd(), overwrite = FALSE,
     )
   )
   
-  # If the user hasn't supplied a filename, use the remote one
-  if (is.null(filename))
-    filename <- remote_filename
+  # If the user hasn't supplied a file_name, use the remote one
+  if (is.null(file_name))
+    file_name <- remote_filename
   
   # The full path for the new file
-  new_file <- suppressWarnings(normalizePath(paste0(local_dir, "/", filename)))
+  new_file <- suppressWarnings(normalizePath(paste0(local_dir, "/", file_name)))
   
   # If the filetype has changed, let them know
   ext <- function(x) {
